# [1.8.10](https://github.com/seriaati/ambr/compare/v1.8.9..v1.8.10) - 2025-12-01

## Continuous Integrations

- Update pre-commit hooks (#132) - ([2ba8c1d](https://github.com/seriaati/ambr/commit/2ba8c1d74b054d3c37a60e1af883e410a587ad18))
- Update pre-commit hooks (#134) - ([ef44749](https://github.com/seriaati/ambr/commit/ef4474945859949f36fe7fe7fb1cb52ab644ae2e))
- Update pre-commit hooks (#136) - ([668de57](https://github.com/seriaati/ambr/commit/668de57a045e1ebb495b84c6a87a430dd4dd2726))
- Update pre-commit hooks (#138) - ([710f4ba](https://github.com/seriaati/ambr/commit/710f4bade06b2032e251fba62b300be606c63261))
- Update pre-commit hooks (#140) - ([79f51e4](https://github.com/seriaati/ambr/commit/79f51e4c9313d61bb7d2162a0c4520e20e59bfdd))
- Update pre-commit hooks (#142) - ([eb7940c](https://github.com/seriaati/ambr/commit/eb7940cb787536f276c608ea2251d8316053142f))

## Miscellaneous Chores

- **(deps)** lock file maintenance (#133) - ([637b52f](https://github.com/seriaati/ambr/commit/637b52f9f8258ab945708f0b868193031e1ae31a))
- **(deps)** lock file maintenance (#135) - ([f75c1f2](https://github.com/seriaati/ambr/commit/f75c1f2b5f15b2265c9f45a53b3fa35fb0daaa0d))
- **(deps)** lock file maintenance (#137) - ([b00bbf8](https://github.com/seriaati/ambr/commit/b00bbf848d37737dbcce4a5a0bb6add21409001f))
- **(deps)** update actions/checkout action to v6 (#139) - ([7ec98d1](https://github.com/seriaati/ambr/commit/7ec98d1276f1a11d2ac37f4b7ccca258f9fa9a5f))
- **(deps)** lock file maintenance (#141) - ([848d43e](https://github.com/seriaati/ambr/commit/848d43ed25171e923024344f8508ce56404e67b1))

<!-- generated by git-cliff -->
